@@ -13,7 +13,7 @@ use JSON qw( from_json );
 use MIME::Base64;
 use Moo;
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 has client_id     => ( is => "rw" );
 has client_secret => ( is => "rw" );
@@ -25,6 +25,7 @@ has homedir => (
   is      => "ro",
   default => glob '~',
 );
+has base_uri    => ( is => "rw" );
 has login_uri   => ( is => "rw" );
 has site        => ( is => "rw" );
 has scope       => ( is => "rw" );
@@ -271,6 +272,8 @@ sub http_get {
     my $uri = URI->new( $url );
     $uri->query_form( @$query ) if defined $query;
 
+    DEBUG "Fetching $uri";
+
     my $resp = $ua->get( $uri, 
         $self->authorization_headers, @$query );
 
@@ -353,6 +356,9 @@ API)
 =item B<OAuth::Cmdline::Youtube>
 - Youtube viewer reports
 
+=item B<OAuth::Cmdline::Smartthings>
+- Smartthings API
+
 =back
 
 But stay tuned, I'll refactor the site-specific parts of the
